﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Infragistics.Olap;
using Infragistics.Olap.FlatData;
using FlatDataWithDistinctCount.Model;
using FlatDataWithDistinctCount.Aggregators;

namespace FlatDataWithDistinctCount
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();

            FlatDataSource flatDataSource = new FlatDataSource();

            // allows multiple dimensions and measures to be generated over the same property
            flatDataSource.DimensionsGenerationMode = DimensionsGenerationMode.Mixed;
            flatDataSource.MetadataTreeItemAdding +=
                (s, e) =>
                    {
                        if (e.Item.Caption == "Measures" || e.Item.ItemType == ItemTypes.Group)
                        {
                            e.Item.ExpandWhenInitialized = true;
                        }
                    };

            CubeMetadata cubeMetadata = new CubeMetadata();
            cubeMetadata.DataTypeFullName = typeof (DataRecord).FullName;
            cubeMetadata.DisplayName = "Meetings";

            flatDataSource.CubesSettings.Add(cubeMetadata);

            // add boys and girls dimensions explicitly because of the additional measures
            // generated over the same property possible by DimensionsGenerationMode.Mixed
            DimensionMetadata boysDimension = new DimensionMetadata();
            boysDimension.SourcePropertyName = "MaleName";
            boysDimension.DisplayName = "Boys";
            boysDimension.DimensionType = DimensionType.Dimension;
            cubeMetadata.DimensionSettings.Add(boysDimension);

            DimensionMetadata girlsDimension = new DimensionMetadata();
            girlsDimension.SourcePropertyName = "FemaleName";
            girlsDimension.DisplayName = "Girls";
            girlsDimension.DimensionType = DimensionType.Dimension;
            cubeMetadata.DimensionSettings.Add(girlsDimension);

            // add different kind of measures
            DimensionMetadata bottomMostMalesCount = new DimensionMetadata();
            bottomMostMalesCount.GroupName = "Bottom Indicators";
            bottomMostMalesCount.SourcePropertyName = "MaleName";
            bottomMostMalesCount.DisplayName = "Bottom Most Active Boys";
            bottomMostMalesCount.DimensionType = DimensionType.Measure;
            bottomMostMalesCount.Aggregator = new FlatDataWithDistinctCount.Aggregators.BottomCountOfStringAggregator();
            cubeMetadata.DimensionSettings.Add(bottomMostMalesCount);

            DimensionMetadata topMostMalesCount = new DimensionMetadata();
            topMostMalesCount.GroupName = "Top Indicators";
            topMostMalesCount.SourcePropertyName = "MaleName";
            topMostMalesCount.DisplayName = "Max Count Per Boys";
            topMostMalesCount.DimensionType = DimensionType.Measure;
            topMostMalesCount.Aggregator = new FlatDataWithDistinctCount.Aggregators.TopCountAggregator();
            cubeMetadata.DimensionSettings.Add(topMostMalesCount);

            DimensionMetadata topMostMales = new DimensionMetadata();
            topMostMales.GroupName = "Top Indicators";
            topMostMales.SourcePropertyName = "MaleName";
            topMostMales.DisplayName = "Top Most Active Boys";
            topMostMales.DimensionType = DimensionType.Measure;
            topMostMales.Aggregator = new FlatDataWithDistinctCount.Aggregators.TopCountOfStringAggregator();
            cubeMetadata.DimensionSettings.Add(topMostMales);

            DimensionMetadata topMostFemales = new DimensionMetadata();
            topMostFemales.GroupName = "Top Indicators";
            topMostFemales.SourcePropertyName = "FemaleName";
            topMostFemales.DisplayName = "Top Most Active Girls";
            topMostFemales.DimensionType = DimensionType.Measure;
            topMostFemales.Aggregator = new FlatDataWithDistinctCount.Aggregators.TopCountOfStringAggregator();
            cubeMetadata.DimensionSettings.Add(topMostFemales);

            DimensionMetadata femalesDistinctCount = new DimensionMetadata();
            femalesDistinctCount.GroupName = "Distinct";
            femalesDistinctCount.SourcePropertyName = "FemaleName";
            femalesDistinctCount.DisplayName = "Girls Met";
            femalesDistinctCount.DimensionType = DimensionType.Measure;
            femalesDistinctCount.Aggregator = new CountAggregators();
            cubeMetadata.DimensionSettings.Add(femalesDistinctCount);

            flatDataSource.ItemsSource = DataModelProvider.GetData();

            this.pivotGrid.DataSource = flatDataSource;
            this.dataSelector.DataSource = flatDataSource;
        }
        
    }
}
